@@ -3,6 +3,7 @@ import pytest
 from .drivers.browsers import browser_os_name_conf
 from ..python_selenium_ctrl_package.conf.rwd.Website import base_url_conf
 
+
 @pytest.fixture
 def testname(request):
     "pytest fixture for testname"
@@ -66,7 +67,8 @@ def browser(request):
         print("Python says:%s" % str(e))
     return name
 
-def pytest_addoption(parser):
+
+def pytest_addoption_base(parser):
     "Method to add the option to ini."
     try:
         parser.addini("rp_uuid", 'help', type="pathlist")
@@ -206,5 +208,3 @@ def pytest_addoption(parser):
     except Exception as e:
         print("Exception when trying to run test: %s" % __file__)
         print("Python says:%s" % str(e))
-
-
